# This file is overwritten during software install.
# Persistent customizations should go in a .local file.
include whitelist-player-common.local

# common whitelist for all media players

whitelist ${DESKTOP}
whitelist ${DOWNLOADS}
whitelist ${MUSIC}
whitelist ${PICTURES}
whitelist ${VIDEOS}
