# This file is overwritten during software install.
# Persistent customizations should go in a .local file.
include allow-bin-sh.local

noblacklist ${PATH}/bash
noblacklist ${PATH}/dash
noblacklist ${PATH}/sh
