# This file is overwritten during software install.
# Persistent customizations should go in a .local file.
include disable-X11.local

warn This file is deprecated; use disable-x11.inc (lowercase) instead.

# Redirect
include disable-x11.inc
