# This file is overwritten during software install.
# Persistent customizations should go in a .local file.
include allow-ruby.local

noblacklist ${PATH}/ruby
noblacklist /usr/lib/ruby
noblacklist /usr/lib64/ruby
